%define upstream_name    DBD-Mock
%define upstream_version 1.58

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Mock database driver for testing
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/DBD/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(DBI) >= 1.300.0
BuildRequires: perl(List::Util) >= 1.270.0
BuildRequires: perl(Module::Build::Tiny) >= 0.35.0
BuildRequires: perl(Test::Exception) >= 0.310.0
BuildRequires: perl(Test::More) >= 0.470.0
BuildArch:  noarch

%description
Testing with databases can be tricky. If you are developing a system
married to a single database then you can make some assumptions about your
environment and ask the user to provide relevant connection information.
But if you need to test a framework that uses DBI, particularly a framework
that uses different types of persistence schemes, then it may be more
useful to simply verify what the framework is trying to do -- ensure the
right SQL is generated and that the correct parameters are bound.
'DBD::Mock' makes it easy to just modify your configuration (presumably
held outside your code) and just use it instead of 'DBD::Foo' (like the
DBD::Pg manpage or the DBD::mysql manpage) in your framework.

There is no distinct area where using this module makes sense. (Some people
may successfully argue that this is a solution looking for a problem...)
Indeed, if you can assume your users have something like the DBD::AnyData
manpage or the DBD::SQLite manpage or if you do not mind creating a
dependency on them then it makes far more sense to use these legitimate
driver implementations and test your application in the real world -- at
least as much of the real world as you can create in your tests...

And if your database handle exists as a package variable or something else
easily replaced at test-time then it may make more sense to use the
Test::MockObject manpage to create a fully dynamic handle. There is an
excellent article by chromatic about using the Test::MockObject manpage in
this and other ways, strongly recommended. (See the SEE ALSO manpage for a
link)

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Build.PL --installdirs=vendor
./Build

%check
./Build test

%install
./Build install --destdir=%{buildroot}

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml
%{_mandir}/man3/*
%perl_vendorlib/DBD

%changelog
* Tue Nov 03 2020 tv <tv> 1.580.0-1.mga8
+ Revision: 1641924
- update to 1.58

* Sat Sep 19 2020 tv <tv> 1.570.0-1.mga8
+ Revision: 1628689
- update to 1.57

* Fri Sep 18 2020 tv <tv> 1.560.0-1.mga8
+ Revision: 1628501
- update to 1.56

* Tue Feb 18 2020 umeabot <umeabot> 1.550.0-2.mga8
+ Revision: 1541833
- Mageia 8 Mass Rebuild

* Thu Jan 02 2020 tv <tv> 1.550.0-1.mga8
+ Revision: 1475552
- update to 1.55

* Mon Dec 23 2019 tv <tv> 1.540.0-1.mga8
+ Revision: 1469734
- update to 1.54

* Wed Dec 04 2019 tv <tv> 1.530.0-1.mga8
+ Revision: 1464257
- update to 1.53

* Tue Oct 29 2019 tv <tv> 1.520.0-1.mga8
+ Revision: 1456538
- update to 1.52

* Thu Oct 24 2019 tv <tv> 1.510.0-1.mga8
+ Revision: 1455601
- update to 1.51

* Wed Oct 23 2019 tv <tv> 1.500.0-1.mga8
+ Revision: 1455418
- update to 1.50

* Sat Sep 14 2019 tv <tv> 1.490.0-1.mga8
+ Revision: 1440576
- update to 1.49

* Sat Sep 07 2019 tv <tv> 1.470.0-1.mga8
+ Revision: 1438272
- update to 1.47

* Wed Sep 19 2018 umeabot <umeabot> 1.450.0-8.mga7
+ Revision: 1267042
- Mageia 7 Mass Rebuild

* Sat Jun 18 2016 pterjan <pterjan> 1.450.0-7.mga6
+ Revision: 1025363
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 1.450.0-6.mga6
+ Revision: 948343
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.450.0-5.mga5
+ Revision: 746278
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.450.0-4.mga5
+ Revision: 684085
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.450.0-3.mga4
+ Revision: 510429
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.450.0-2.mga3
+ Revision: 365003
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 06 2012 jquelin <jquelin> 1.450.0-1.mga3
+ Revision: 314895
- update to 1.45

* Tue Aug 30 2011 jquelin <jquelin> 1.430.0-1.mga2
+ Revision: 136580
- update to 1.43
- update to 1.42
+ kharec <kharec>
- update to 1.41

* Wed Jan 19 2011 jquelin <jquelin> 1.390.0-1.mga1
+ Revision: 23838
- cleaning spec file
- imported package perl-DBD-Mock

